==> libspring-java_3.2.13.orig.tar.xz: spring-framework-3.2.13/spring-web/src/test/java/org/springframework/web/method/support/ModelAndViewContainerTests.java <==
/*
 * Copyright 2002-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.web.method.support;

import static org.junit.Assert.assertEquals;

import org.junit.Before;
import org.junit.Test;
import org.springframework.ui.ModelMap;

/**
 * Test fixture for {@link ModelAndViewContainer}.
 *
 * @author Rossen Stoyanchev
 * @since 3.1
 */
public class ModelAndViewContainerTests {

	private ModelAndViewContainer mavContainer;

	@Before
	public void setup() {
		this.mavContainer = new ModelAndViewContainer();
	}

	@Test
	public void getModel() {
		this.mavContainer.addAttribute("name", "value");
		assertEquals(1, this.mavContainer.getModel().size());
	}

	@Test
	public void getModelRedirectModel() {
		ModelMap redirectModel = new ModelMap("name", "redirectValue");
		this.mavContainer.setRedirectModel(redirectModel);
		this.mavContainer.addAttribute("name", "value");

		assertEquals("Default model should be used if not in redirect scenario",
				"value", this.mavContainer.getModel().get("name"));

		this.mavContainer.setRedirectModelScenario(true);

		assertEquals("Redirect model should be used in redirect scenario",
				"redirectValue", this.mavContainer.getModel().get("name"));
	}

	@Test
	public void getModelIgnoreDefaultModelOnRedirect() {
		this.mavContainer.addAttribute("name", "value");
		this.mavContainer.setRedirectModelScenario(true);

		assertEquals("Default model should be used since no redirect model was provided",
				1, this.mavContainer.getModel().size());

		this.mavContainer.setIgnoreDefaultModelOnRedirect(true);

		assertEquals("Empty model should be returned if no redirect model is available",
				0, this.mavContainer.getModel().size());
	}

}

==> libspring-java_4.1.9.orig.tar.xz: spring-framework-4.1.9/spring-web/src/test/java/org/springframework/web/method/support/ModelAndViewContainerTests.java <==
/*
 * Copyright 2002-2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.web.method.support;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import org.junit.Before;
import org.junit.Test;
import org.springframework.ui.ModelMap;


/**
 * Test fixture for {@link ModelAndViewContainer}.
 *
 * @author Rossen Stoyanchev
 * @since 3.1
 */
public class ModelAndViewContainerTests {

	private ModelAndViewContainer mavContainer;


	@Before
	public void setup() {
		this.mavContainer = new ModelAndViewContainer();
	}


	@Test
	public void getModel() {
		this.mavContainer.addAttribute("name", "value");
		assertEquals(1, this.mavContainer.getModel().size());
		assertEquals("value", this.mavContainer.getModel().get("name"));
	}

	@Test
	public void redirectScenarioWithRedirectModel() {
		this.mavContainer.addAttribute("name1", "value1");
		this.mavContainer.setRedirectModel(new ModelMap("name2", "value2"));
		this.mavContainer.setRedirectModelScenario(true);

		assertEquals(1, this.mavContainer.getModel().size());
		assertEquals("value2", this.mavContainer.getModel().get("name2"));
	}

	@Test
	public void redirectScenarioWithoutRedirectModel() {
		this.mavContainer.addAttribute("name", "value");
		this.mavContainer.setRedirectModelScenario(true);

		assertEquals(1, this.mavContainer.getModel().size());
		assertEquals("value", this.mavContainer.getModel().get("name"));
	}

	@Test
	public void ignoreDefaultModel() {
		this.mavContainer.setIgnoreDefaultModelOnRedirect(true);
		this.mavContainer.addAttribute("name", "value");
		this.mavContainer.setRedirectModelScenario(true);

		assertTrue(this.mavContainer.getModel().isEmpty());
	}

}
